@@ -1,3 +1,4 @@
+import re
 from concurrent.futures import ThreadPoolExecutor
 from typing import (
     Any,
@@ -11,12 +12,6 @@ from typing import (
     Union,
 )
 
-from metaphor.bigquery.logEvent import JobChangeEvent
-from metaphor.common.entity_id import dataset_normalized_name
-from metaphor.common.query_history import chunk_query_logs
-from metaphor.common.tag_matcher import tag_datasets
-from metaphor.common.utils import md5_digest, start_of_day
-
 try:
     import google.cloud.bigquery as bigquery
     from google.cloud import logging_v2
@@ -25,12 +20,17 @@ except ImportError:
     raise
 
 from metaphor.bigquery.config import BigQueryRunConfig
+from metaphor.bigquery.logEvent import JobChangeEvent
 from metaphor.bigquery.utils import LogEntry, build_client, build_logging_client
 from metaphor.common.base_extractor import BaseExtractor
+from metaphor.common.entity_id import dataset_normalized_name
 from metaphor.common.event_util import ENTITY_TYPES
 from metaphor.common.fieldpath import FieldDataType, build_field_path
 from metaphor.common.filter import DatasetFilter
 from metaphor.common.logger import get_logger
+from metaphor.common.query_history import chunk_query_logs
+from metaphor.common.tag_matcher import tag_datasets
+from metaphor.common.utils import md5_digest, start_of_day
 from metaphor.models.crawler_run_metadata import Platform
 from metaphor.models.metadata_change_event import (
     DataPlatform,
@@ -45,6 +45,7 @@ from metaphor.models.metadata_change_event import (
     SchemaField,
     SchemaType,
     SQLSchema,
+    TypeEnum,
 )
 
 logger = get_logger()
@@ -73,6 +74,9 @@ class BigQueryExtractor(BaseExtractor):
             config.query_log.exclude_service_accounts
         )
         self._query_log_fetch_size = config.query_log.fetch_size
+        self._fetch_job_query_if_truncated = (
+            config.query_log.fetch_job_query_if_truncated
+        )
 
     async def extract(self) -> Collection[ENTITY_TYPES]:
         logger.info(f"Fetching metadata from BigQuery project {self._project_id}")
@@ -120,7 +124,7 @@ class BigQueryExtractor(BaseExtractor):
             fetched_tables.extend(tables.values())
 
         logger.info("Fetching BigQueryAuditMetadata")
-        query_logs = self._fetch_query_logs(logging_client)
+        query_logs = self._fetch_query_logs(logging_client, client)
 
         tag_datasets(fetched_tables, self._tag_matchers)
 
@@ -264,7 +268,9 @@ class BigQueryExtractor(BaseExtractor):
             last_updated=bq_table.modified,
         )
 
-    def _fetch_query_logs(self, logging_client: logging_v2.Client) -> List[QueryLog]:
+    def _fetch_query_logs(
+        self, logging_client: logging_v2.Client, client: bigquery.Client
+    ) -> List[QueryLog]:
         logs: List[Optional[QueryLog]] = []
         log_filter = self._build_job_change_filter()
 
@@ -272,7 +278,7 @@ class BigQueryExtractor(BaseExtractor):
             page_size=self._query_log_fetch_size, filter_=log_filter
         ):
             if JobChangeEvent.can_parse(entry):
-                logs.append(self._parse_job_change_entry(entry))
+                logs.append(self._parse_job_change_entry(entry, client))
 
             if len(logs) % 1000 == 0:
                 logger.info(f"Fetched {len(logs)} audit logs")
@@ -281,7 +287,28 @@ class BigQueryExtractor(BaseExtractor):
 
         return [log for log in logs if log is not None]
 
-    def _parse_job_change_entry(self, entry: LogEntry) -> Optional[QueryLog]:
+    @staticmethod
+    def _fetch_job_query(client: bigquery.Client, job_name: str) -> Optional[str]:
+        logger.info(f"Query {job_name}")
+        match = re.match(r"^projects/([^/]+)/jobs/([^/]+)$", job_name)
+        if match:
+            project = match.group(1)
+            job_id = match.group(2)
+
+            try:
+                job = client.get_job(job_id, project)
+            except Exception as e:
+                logger.warning(f"Failed to get job information: {e}")
+                return None
+
+            if isinstance(job, bigquery.QueryJob):
+                return job.query
+
+        return None
+
+    def _parse_job_change_entry(
+        self, entry: LogEntry, client: bigquery.Client
+    ) -> Optional[QueryLog]:
         job_change = JobChangeEvent.from_entry(entry)
         if job_change is None or job_change.query is None:
             return None
@@ -307,6 +334,19 @@ class BigQueryExtractor(BaseExtractor):
             else None
         )
 
+        default_database, default_schema = None, None
+        if job_change.default_dataset and job_change.default_dataset.count(".") == 1:
+            default_database, default_schema = job_change.default_dataset.split(".")
+
+        query: Optional[str] = job_change.query
+        # if query SQL is truncated, fetch full SQL from job API
+        if (
+            job_change.job_type == "QUERY"
+            and job_change.query_truncated
+            and self._fetch_job_query_if_truncated
+        ):
+            query = self._fetch_job_query(client, job_change.job_name) or query
+
         elapsed_time = (
             (job_change.end_time - job_change.start_time).total_seconds()
             if job_change.start_time and job_change.end_time
@@ -331,10 +371,43 @@ class BigQueryExtractor(BaseExtractor):
             else None,
             sources=sources,
             targets=target_datasets,
-            sql=job_change.query,
+            default_database=default_database,
+            default_schema=default_schema,
+            type=self._map_query_type(job_change.statementType)
+            if job_change.statementType
+            else None,
+            sql=query,
             sql_hash=md5_digest(job_change.query.encode("utf-8")),
         )
 
+    # https://cloud.google.com/bigquery/docs/reference/auditlogs/rest/Shared.Types/BigQueryAuditMetadata.QueryStatementType
+    _query_type_map = {
+        "SELECT": TypeEnum.SELECT,
+        "INSERT": TypeEnum.INSERT,
+        "UPDATE": TypeEnum.UPDATE,
+        "DELETE": TypeEnum.DELETE,
+        "MERGE": TypeEnum.MERGE,
+        "CREATE_TABLE": TypeEnum.CREATE_TABLE,
+        "CREATE_TABLE_AS_SELECT": TypeEnum.CREATE_TABLE,
+        "CREATE_SNAPSHOT_TABLE": TypeEnum.CREATE_TABLE,
+        "CREATE_VIEW": TypeEnum.CREATE_VIEW,
+        "CREATE_MATERIALIZED_VIEW": TypeEnum.CREATE_VIEW,
+        "DROP_TABLE": TypeEnum.DROP_TABLE,
+        "DROP_EXTERNAL_TABLE": TypeEnum.DROP_TABLE,
+        "DROP_SNAPSHOT_TABLE": TypeEnum.DROP_TABLE,
+        "DROP_VIEW": TypeEnum.DROP_VIEW,
+        "DROP_MATERIALIZED_VIEW": TypeEnum.DROP_VIEW,
+        "ALTER_TABLE": TypeEnum.ALTER_TABLE,
+        "ALTER_VIEW": TypeEnum.ALTER_VIEW,
+        "ALTER_MATERIALIZED_VIEW": TypeEnum.ALTER_VIEW,
+        "TRUNCATE_TABLE": TypeEnum.TRUNCATE,
+        "EXPORT_DATA": TypeEnum.EXPORT,
+    }
+
+    @staticmethod
+    def _map_query_type(query_type: str) -> TypeEnum:
+        return BigQueryExtractor._query_type_map.get(query_type.upper(), TypeEnum.OTHER)
+
     def _build_job_change_filter(self) -> str:
         start_time = start_of_day(self._query_log_lookback_days).isoformat()
         end_time = start_of_day().isoformat()
