@@ -1,4 +1,4 @@
-from typing import Optional
+from typing import Optional, Type, TypeVar
 
 import yaml
 from pydantic import parse_obj_as
@@ -9,6 +9,9 @@ from metaphor.common.api_sink import ApiSinkConfig
 from metaphor.common.file_sink import FileSinkConfig
 from metaphor.common.variable import variable_substitution
 
+# Create a generic variable that can be 'BaseConfig', or any subclass.
+T = TypeVar("T", bound="BaseConfig")
+
 
 @dataclass
 class OutputConfig:
@@ -28,7 +31,7 @@ class BaseConfig:
     output: OutputConfig
 
     @classmethod
-    def from_yaml_file(cls, path: str) -> "BaseConfig":
+    def from_yaml_file(cls: Type[T], path: str) -> T:
         with open(path, encoding="utf8") as fin:
             obj = yaml.safe_load(fin.read())
             return parse_obj_as(cls, variable_substitution(obj))
