@@ -112,7 +112,7 @@ class DatasetFilter:
             if schema_filter is None:
                 return True
 
-            for (pattern, table_filter) in schema_filter.items():
+            for pattern, table_filter in schema_filter.items():
                 if self._accepted_by_schema_pattern(
                     schema_name, table_name, pattern, table_filter
                 ):
@@ -193,3 +193,16 @@ class DatasetFilter:
             return False
 
         return True
+
+    def include_database(
+        self,
+        database_name: str,
+    ) -> bool:
+        if not self.includes or len(self.includes) == 0:
+            return True
+
+        database_lower = database_name.lower()
+        for pattern in self.includes:
+            if fnmatch(database_lower, pattern):
+                return True
+        return False
