@@ -1,8 +1,9 @@
-from typing import Optional
+from dataclasses import field
 
 from pydantic.dataclasses import dataclass
 
 from metaphor.common.base_config import BaseConfig
+from metaphor.common.filter import DatasetFilter
 
 
 @dataclass
@@ -14,10 +15,13 @@ class MssqlConfig(BaseConfig):
     password: str
 
     # SQL Server endpoint. Instead of Azure SQL endpoint if specified
-    endpoint: str
+    endpoint: str = ""
 
     # Azure Directory (tenant) ID
-    tenant_id: Optional[str] = ""
+    tenant_id: str = ""
 
     # SQL Server name
-    server_name: Optional[str] = ""
+    server_name: str = ""
+
+    # Include or exclude specific databases/schemas/tables
+    filter: DatasetFilter = field(default_factory=lambda: DatasetFilter())
