@@ -43,11 +43,8 @@ class MssqlExtractor(BaseExtractor):
     ):
         super().__init__(config, description, platform)
         self._config = config
-        self._config.server_name = (
-            self._config.server_name
-            if self._config.server_name
-            else self._config.endpoint
-        )
+        self._config.server_name = self._config.server_name or self._config.endpoint
+        self._filter = config.filter.normalize()
         self._platform = platform
         self._dataset_platform = dataset_platform
 
@@ -61,6 +58,8 @@ class MssqlExtractor(BaseExtractor):
         entities: List[ENTITY_TYPES] = []
         try:
             for database in client.get_databases():
+                if not self._filter.include_database(database.name):
+                    continue
                 tables = client.get_tables(database.name)
                 datasets = self._map_tables_to_dataset(
                     self._config.server_name, database, tables
@@ -82,6 +81,10 @@ class MssqlExtractor(BaseExtractor):
             return dataset_map
 
         for table in tables:
+            if not self._filter.include_table(
+                database.name, table.schema_name, table.name
+            ):
+                continue
             dataset = Dataset()
             dataset.created_at = table.create_time
             dataset.entity_type = EntityType.DATASET
@@ -147,7 +150,9 @@ class MssqlExtractor(BaseExtractor):
             if fk.table_id in dataset_map:
                 foreign_key = ForeignKey(
                     field_path=fk.column_name,
-                    parent=dataset_map[fk.referenced_table_id].logical_id,
+                    parent=dataset_map[fk.referenced_table_id].logical_id
+                    if fk.referenced_table_id in dataset_map
+                    else None,
                     parent_field=fk.referenced_column,
                 )
                 dataset_map[fk.table_id].schema.sql_schema.foreign_key.append(
