@@ -1,5 +1,4 @@
 import tempfile
-from enum import Enum
 from time import sleep
 from typing import Any, Callable, List, Optional, Type, TypeVar
 
@@ -75,16 +74,9 @@ class PowerBITile(BaseModel):
     embedUrl: Optional[str]
 
 
-class PowerBIRefreshStatus(Enum):
-    UNKNOWN = "Unknown"
-    COMPLETED = "Completed"
-    FAILED = "Failed"
-    DISABLED = "Disabled"
-
-
 class PowerBIRefresh(BaseModel):
-    status: PowerBIRefreshStatus
-    endTime: str
+    status: str = ""
+    endTime: str = ""
 
 
 class PowerBITableColumn(BaseModel):
@@ -142,6 +134,11 @@ class WorkspaceInfo(BaseModel):
     dashboards: List[WorkspaceInfoDashboard] = []
 
 
+class AccessTokenError(Exception):
+    def __init__(self, message: str) -> None:
+        super().__init__(f"Failed to acquire access token: {message}")
+
+
 class AuthenticationError(Exception):
     def __init__(self, body) -> None:
         super().__init__(
@@ -185,7 +182,11 @@ class PowerBIClient:
             )
             token = app.acquire_token_for_client(scopes=self.SCOPES)
 
-        return f"Bearer {token['access_token']}"
+        access_token = token.get("access_token")
+        if access_token is None:
+            raise AccessTokenError(token.get("error_description", "unknown error"))
+
+        return f"Bearer {access_token}"
 
     def get_groups(self) -> List[PowerBIWorkspace]:
         # https://docs.microsoft.com/en-us/rest/api/power-bi/admin/groups-get-groups-as-admin
@@ -250,7 +251,13 @@ class PowerBIClient:
                 f"Unable to find report {report_id} in workspace {group_id}. "
                 f"Please add the service principal as a viewer to the workspace"
             )
-            return []
+        except Exception as e:
+            # Fail gracefully for any other errors
+            logger.error(
+                f"Failed to get pages from report {report_id} in workspace {group_id}: {e}"
+            )
+
+        return []
 
     def get_refreshes(self, group_id: str, dataset_id: str) -> List[PowerBIRefresh]:
         # https://docs.microsoft.com/en-us/rest/api/power-bi/datasets/get-refresh-history-in-group
@@ -267,7 +274,13 @@ class PowerBIClient:
                 f"Unable to find dataset {dataset_id} in workspace {group_id}. "
                 f"Please add the service principal as a viewer to the workspace"
             )
-            return []
+        except Exception as e:
+            # Fail gracefully for any other errors
+            logger.error(
+                f"Failed to get pages from dataset {dataset_id} in workspace {group_id}: {e}"
+            )
+
+        return []
 
     def get_workspace_info(self, workspace_ids: List[str]) -> List[WorkspaceInfo]:
         def create_scan() -> str:
@@ -285,6 +298,7 @@ class PowerBIClient:
                     "lineage": True,
                 },
                 data=request_body,
+                timeout=600,  # request timeout 600s
             )
 
             assert result.status_code == 202, (
@@ -305,7 +319,7 @@ class PowerBIClient:
             waiting_time = 0
             sleep_time = 1
             while True:
-                result = requests.get(url, headers=self._headers)
+                result = requests.get(url, headers=self._headers, timeout=600)
                 if result.status_code != 200:
                     return False
                 if result.json()["status"] == "Succeeded":
