@@ -1,9 +1,10 @@
 from dataclasses import field
-from typing import Set
+from typing import List, Set
 
 from pydantic.dataclasses import dataclass
 
 from metaphor.common.filter import DatasetFilter
+from metaphor.common.tag_matcher import TagMatcher
 from metaphor.snowflake.auth import SnowflakeAuthConfig
 from metaphor.snowflake.utils import DEFAULT_THREAD_POOL_SIZE
 
@@ -13,7 +14,6 @@ DEFAULT_QUERY_LOG_FETCH_SIZE = 100000
 
 @dataclass
 class SnowflakeQueryLogConfig:
-
     # Number of days back of query logs to fetch, if 0, don't fetch query logs
     lookback_days: int = 1
 
@@ -26,15 +26,14 @@ class SnowflakeQueryLogConfig:
 
 @dataclass
 class SnowflakeRunConfig(SnowflakeAuthConfig):
-
     # Include or exclude specific databases/schemas/tables
     filter: DatasetFilter = field(default_factory=lambda: DatasetFilter())
 
-    # Whether to fetch extra table information such as LAST_CHANGE_COMMIT_TIME and DDL
-    fetch_extra_table_info: bool = True
-
     # Max number of concurrent queries to database
     max_concurrency: int = DEFAULT_THREAD_POOL_SIZE
 
+    # How tags should be assigned to datasets
+    tag_matchers: List[TagMatcher] = field(default_factory=lambda: [])
+
     # configs for fetching query logs
     query_log: SnowflakeQueryLogConfig = SnowflakeQueryLogConfig()
